@@ -64,8 +64,8 @@ def test_origin():
 
 
 def test_origin_nonascii():
-    url = URL("http://user:password@историк.рф:8888/path/to?a=1&b=2")
-    assert str(url.origin()) == "http://xn--h1aagokeh.xn--p1ai:8888"
+    url = URL("http://user:password@оун-упа.укр:8888/path/to?a=1&b=2")
+    assert str(url.origin()) == "http://xn----8sb1bdhvc.xn--j1amh:8888"
 
 
 def test_origin_ipv6():
@@ -117,8 +117,8 @@ def test_raw_user():
 
 
 def test_raw_user_non_ascii():
-    url = URL("http://вася@example.com")
-    assert "%D0%B2%D0%B0%D1%81%D1%8F" == url.raw_user
+    url = URL("http://бажан@example.com")
+    assert "%D0%B1%D0%B0%D0%B6%D0%B0%D0%BD" == url.raw_user
 
 
 def test_no_user():
@@ -127,8 +127,8 @@ def test_no_user():
 
 
 def test_user_non_ascii():
-    url = URL("http://вася@example.com")
-    assert "вася" == url.user
+    url = URL("http://бажан@example.com")
+    assert "бажан" == url.user
 
 
 def test_raw_password():
@@ -164,13 +164,13 @@ def test_raw_host():
 
 
 def test_raw_host_non_ascii():
-    url = URL("http://историк.рф")
-    assert "xn--h1aagokeh.xn--p1ai" == url.raw_host
+    url = URL("http://оун-упа.укр")
+    assert "xn----8sb1bdhvc.xn--j1amh" == url.raw_host
 
 
 def test_host_non_ascii():
-    url = URL("http://историк.рф")
-    assert "историк.рф" == url.host
+    url = URL("http://оун-упа.укр")
+    assert "оун-упа.укр" == url.host
 
 
 def test_localhost():
@@ -210,12 +210,13 @@ def test_authority_short() -> None:
 
 
 def test_authority_full_nonasci() -> None:
-    url = URL("http://ваня:пароль@айдеко.рф:8080/path")
+    url = URL("http://степан:пароль@слава.укр:8080/path")
     assert url.raw_authority == (
-        "%D0%B2%D0%B0%D0%BD%D1%8F:%D0%BF%D0%B0%D1%80%D0%BE%D0%BB%D1%8C@"
-        "xn--80aidohy.xn--p1ai:8080"
+        "%D1%81%D1%82%D0%B5%D0%BF%D0%B0%D0%BD:"
+        "%D0%BF%D0%B0%D1%80%D0%BE%D0%BB%D1%8C@"
+        "xn--80aaf8a3a.xn--j1amh:8080"
     )
-    assert url.authority == "ваня:пароль@айдеко.рф:8080"
+    assert url.authority == "степан:пароль@слава.укр:8080"
 
 
 def test_lowercase():
@@ -225,9 +226,9 @@ def test_lowercase():
 
 
 def test_lowercase_nonascii():
-    url = URL("http://Айдеко.Рф")
-    assert url.raw_host == "xn--80aidohy.xn--p1ai"
-    assert url.host == "айдеко.рф"
+    url = URL("http://Слава.Укр")
+    assert url.raw_host == "xn--80aaf8a3a.xn--j1amh"
+    assert url.host == "слава.укр"
 
 
 def test_compressed_ipv6():
@@ -294,13 +295,13 @@ def test_raw_path():
 
 
 def test_raw_path_non_ascii():
-    url = URL("http://example.com/путь/сюда")
-    assert "/%D0%BF%D1%83%D1%82%D1%8C/%D1%81%D1%8E%D0%B4%D0%B0" == url.raw_path
+    url = URL("http://example.com/шлях/сюди")
+    assert "/%D1%88%D0%BB%D1%8F%D1%85/%D1%81%D1%8E%D0%B4%D0%B8" == url.raw_path
 
 
 def test_path_non_ascii():
-    url = URL("http://example.com/путь/сюда")
-    assert "/путь/сюда" == url.path
+    url = URL("http://example.com/шлях/сюди")
+    assert "/шлях/сюди" == url.path
 
 
 def test_path_with_spaces():
@@ -352,8 +353,8 @@ def test_raw_path_qs():
     assert url.raw_path_qs == "/?%D0%B1=%D0%B2&%D1%8E=%D0%BA"
     url = URL("http://example.com/path?б=в&ю=к")
     assert url.raw_path_qs == "/path?%D0%B1=%D0%B2&%D1%8E=%D0%BA"
-    url = URL("http://example.com/путь?a=1&b=2")
-    assert url.raw_path_qs == "/%D0%BF%D1%83%D1%82%D1%8C?a=1&b=2"
+    url = URL("http://example.com/шлях?a=1&b=2")
+    assert url.raw_path_qs == "/%D1%88%D0%BB%D1%8F%D1%85?a=1&b=2"
 
 
 def test_query_string_spaces():
@@ -375,8 +376,8 @@ def test_raw_fragment():
 
 
 def test_raw_fragment_non_ascii():
-    url = URL("http://example.com/path#якорь")
-    assert "%D1%8F%D0%BA%D0%BE%D1%80%D1%8C" == url.raw_fragment
+    url = URL("http://example.com/path#якір")
+    assert "%D1%8F%D0%BA%D1%96%D1%80" == url.raw_fragment
 
 
 def test_raw_fragment_safe():
@@ -385,8 +386,8 @@ def test_raw_fragment_safe():
 
 
 def test_fragment_non_ascii():
-    url = URL("http://example.com/path#якорь")
-    assert "якорь" == url.fragment
+    url = URL("http://example.com/path#якір")
+    assert "якір" == url.fragment
 
 
 def test_raw_parts_empty():
@@ -435,17 +436,17 @@ def test_parts_for_empty_url():
 
 
 def test_raw_parts_non_ascii():
-    url = URL("http://example.com/путь/сюда")
+    url = URL("http://example.com/шлях/сюди")
     assert (
         "/",
-        "%D0%BF%D1%83%D1%82%D1%8C",
-        "%D1%81%D1%8E%D0%B4%D0%B0",
+        "%D1%88%D0%BB%D1%8F%D1%85",
+        "%D1%81%D1%8E%D0%B4%D0%B8",
     ) == url.raw_parts
 
 
 def test_parts_non_ascii():
-    url = URL("http://example.com/путь/сюда")
-    assert ("/", "путь", "сюда") == url.parts
+    url = URL("http://example.com/шлях/сюди")
+    assert ("/", "шлях", "сюди") == url.parts
 
 
 def test_name_for_empty_url():
@@ -489,8 +490,8 @@ def test_relative_raw_name_slash():
 
 
 def test_name_non_ascii():
-    url = URL("http://example.com/путь")
-    assert url.name == "путь"
+    url = URL("http://example.com/шлях")
+    assert url.name == "шлях"
 
 
 def test_suffix_for_empty_url():
@@ -534,8 +535,8 @@ def test_relative_raw_suffix_dot():
 
 
 def test_suffix_non_ascii():
-    url = URL("http://example.com/путь.суффикс")
-    assert url.suffix == ".суффикс"
+    url = URL("http://example.com/шлях.суфікс")
+    assert url.suffix == ".суфікс"
 
 
 def test_suffix_with_empty_name():
@@ -594,8 +595,8 @@ def test_relative_raw_suffixes_dot():
 
 
 def test_suffixes_non_ascii():
-    url = URL("http://example.com/путь.суффикс")
-    assert url.suffixes == (".суффикс",)
+    url = URL("http://example.com/шлях.суфікс")
+    assert url.suffixes == (".суфікс",)
 
 
 def test_suffixes_with_empty_name():
@@ -753,15 +754,15 @@ def test_div_for_relative_url_started_with_slash():
 
 
 def test_div_non_ascii():
-    url = URL("http://example.com/сюда")
-    url2 = url / "туда"
-    assert url2.path == "/сюда/туда"
-    assert url2.raw_path == "/%D1%81%D1%8E%D0%B4%D0%B0/%D1%82%D1%83%D0%B4%D0%B0"
-    assert url2.parts == ("/", "сюда", "туда")
+    url = URL("http://example.com/сюди")
+    url2 = url / "туди"
+    assert url2.path == "/сюди/туди"
+    assert url2.raw_path == "/%D1%81%D1%8E%D0%B4%D0%B8/%D1%82%D1%83%D0%B4%D0%B8"
+    assert url2.parts == ("/", "сюди", "туди")
     assert url2.raw_parts == (
         "/",
-        "%D1%81%D1%8E%D0%B4%D0%B0",
-        "%D1%82%D1%83%D0%B4%D0%B0",
+        "%D1%81%D1%8E%D0%B4%D0%B8",
+        "%D1%82%D1%83%D0%B4%D0%B8",
     )
 
 
@@ -846,13 +847,13 @@ def test_joinpath_relative(url, to_join, expected):
     "url,to_join,encoded,e_path,e_raw_path,e_parts,e_raw_parts",
     [
         pytest.param(
-            "http://example.com/сюда",
-            ("туда",),
+            "http://example.com/сюди",
+            ("туди",),
             False,
-            "/сюда/туда",
-            "/%D1%81%D1%8E%D0%B4%D0%B0/%D1%82%D1%83%D0%B4%D0%B0",
-            ("/", "сюда", "туда"),
-            ("/", "%D1%81%D1%8E%D0%B4%D0%B0", "%D1%82%D1%83%D0%B4%D0%B0"),
+            "/сюди/туди",
+            "/%D1%81%D1%8E%D0%B4%D0%B8/%D1%82%D1%83%D0%B4%D0%B8",
+            ("/", "сюди", "туди"),
+            ("/", "%D1%81%D1%8E%D0%B4%D0%B8", "%D1%82%D1%83%D0%B4%D0%B8"),
             id="non-ascii",
         ),
         pytest.param(
@@ -1093,11 +1094,11 @@ def test_with_name_empty():
 
 
 def test_with_name_non_ascii():
-    url = URL("http://example.com/path").with_name("путь")
-    assert url.path == "/путь"
-    assert url.raw_path == "/%D0%BF%D1%83%D1%82%D1%8C"
-    assert url.parts == ("/", "путь")
-    assert url.raw_parts == ("/", "%D0%BF%D1%83%D1%82%D1%8C")
+    url = URL("http://example.com/path").with_name("шлях")
+    assert url.path == "/шлях"
+    assert url.raw_path == "/%D1%88%D0%BB%D1%8F%D1%85"
+    assert url.parts == ("/", "шлях")
+    assert url.raw_parts == ("/", "%D1%88%D0%BB%D1%8F%D1%85")
 
 
 def test_with_name_percent_encoded():
@@ -1185,11 +1186,11 @@ def test_with_suffix_empty():
 
 
 def test_with_suffix_non_ascii():
-    url = URL("http://example.com/path").with_suffix(".путь")
-    assert url.path == "/path.путь"
-    assert url.raw_path == "/path.%D0%BF%D1%83%D1%82%D1%8C"
-    assert url.parts == ("/", "path.путь")
-    assert url.raw_parts == ("/", "path.%D0%BF%D1%83%D1%82%D1%8C")
+    url = URL("http://example.com/path").with_suffix(".шлях")
+    assert url.path == "/path.шлях"
+    assert url.raw_path == "/path.%D1%88%D0%BB%D1%8F%D1%85"
+    assert url.parts == ("/", "path.шлях")
+    assert url.raw_parts == ("/", "path.%D1%88%D0%BB%D1%8F%D1%85")
 
 
 def test_with_suffix_percent_encoded():
@@ -1340,8 +1341,8 @@ def test_from_ascii_login():
 
 
 def test_from_non_ascii_login():
-    url = URL("http://вася@host:1234/")
-    assert ("http://" "%D0%B2%D0%B0%D1%81%D1%8F" "@host:1234/") == str(url)
+    url = URL("http://бажан@host:1234/")
+    assert ("http://%D0%B1%D0%B0%D0%B6%D0%B0%D0%BD@host:1234/") == str(url)
 
 
 def test_from_ascii_login_and_password():
@@ -1360,10 +1361,10 @@ def test_from_ascii_login_and_password():
 
 
 def test_from_non_ascii_login_and_password():
-    url = URL("http://вася:пароль@host:1234/")
+    url = URL("http://бажан:пароль@host:1234/")
     assert (
         "http://"
-        "%D0%B2%D0%B0%D1%81%D1%8F"
+        "%D0%B1%D0%B0%D0%B6%D0%B0%D0%BD"
         ":%D0%BF%D0%B0%D1%80%D0%BE%D0%BB%D1%8C"
         "@host:1234/"
     ) == str(url)
@@ -1384,16 +1385,16 @@ def test_from_ascii_path_lower_case():
 
 
 def test_from_non_ascii_path():
-    url = URL("http://example.com/путь/туда")
+    url = URL("http://example.com/шлях/туди")
     assert (
-        "http://example.com/" "%D0%BF%D1%83%D1%82%D1%8C/%D1%82%D1%83%D0%B4%D0%B0"
+        "http://example.com/%D1%88%D0%BB%D1%8F%D1%85/%D1%82%D1%83%D0%B4%D0%B8"
     ) == str(url)
 
 
 def test_bytes():
-    url = URL("http://example.com/путь/туда")
+    url = URL("http://example.com/шлях/туди")
     assert (
-        b"http://example.com/%D0%BF%D1%83%D1%82%D1%8C/%D1%82%D1%83%D0%B4%D0%B0"
+        b"http://example.com/%D1%88%D0%BB%D1%8F%D1%85/%D1%82%D1%83%D0%B4%D0%B8"
         == bytes(url)
     )
 
@@ -1610,23 +1611,23 @@ def test_split_result_non_decoded():
 
 
 def test_human_repr():
-    url = URL("http://вася:пароль@хост.домен:8080/путь/сюда?арг=вал#фраг")
+    url = URL("http://бажан:пароль@хост.домен:8080/шлях/сюди?арг=вал#фраг")
     s = url.human_repr()
     assert URL(s) == url
-    assert s == "http://вася:пароль@хост.домен:8080/путь/сюда?арг=вал#фраг"
+    assert s == "http://бажан:пароль@хост.домен:8080/шлях/сюди?арг=вал#фраг"
 
 
 def test_human_repr_defaults():
-    url = URL("путь")
+    url = URL("шлях")
     s = url.human_repr()
-    assert s == "путь"
+    assert s == "шлях"
 
 
 def test_human_repr_default_port():
-    url = URL("http://вася:пароль@хост.домен/путь/сюда?арг=вал#фраг")
+    url = URL("http://бажан:пароль@хост.домен/шлях/сюди?арг=вал#фраг")
     s = url.human_repr()
     assert URL(s) == url
-    assert s == "http://вася:пароль@хост.домен/путь/сюда?арг=вал#фраг"
+    assert s == "http://бажан:пароль@хост.домен/шлях/сюди?арг=вал#фраг"
 
 
 def test_human_repr_ipv6():
@@ -1667,20 +1668,20 @@ def test_human_repr_delimiters():
 def test_human_repr_non_printable():
     url = URL.build(
         scheme="http",
-        user="вася\n\xad\u200b",
+        user="бажан\n\xad\u200b",
         password="пароль\n\xad\u200b",
         host="хост.домен",
         port=8080,
-        path="/путь\n\xad\u200b",
+        path="/шлях\n\xad\u200b",
         query={"арг\n\xad\u200b": "вал\n\xad\u200b"},
         fragment="фраг\n\xad\u200b",
     )
     s = url.human_repr()
     assert URL(s) == url
     assert (
-        s == "http://вася%0A%C2%AD%E2%80%8B:пароль%0A%C2%AD%E2%80%8B"
+        s == "http://бажан%0A%C2%AD%E2%80%8B:пароль%0A%C2%AD%E2%80%8B"
         "@хост.домен:8080"
-        "/путь%0A%C2%AD%E2%80%8B"
+        "/шлях%0A%C2%AD%E2%80%8B"
         "?арг%0A%C2%AD%E2%80%8B=вал%0A%C2%AD%E2%80%8B"
         "#фраг%0A%C2%AD%E2%80%8B"
     )
